summaryrefslogtreecommitdiff
path: root/setup.py
diff options
context:
space:
mode:
authorJonathan Lange <jml@canonical.com>2008-10-04 13:51:34 +1000
committerJonathan Lange <jml@canonical.com>2008-10-04 13:51:34 +1000
commit48592baf729054daf1aada29f7758b22ee9c41e6 (patch)
treeb53aabd59bc5c0c525e7d92648501b54d6097d4e /setup.py
parentd8b2e575fe42e4ee25c176ddfc09d6c26d9cf3e4 (diff)
downloadtesttools-48592baf729054daf1aada29f7758b22ee9c41e6.tar.gz
Rename pyunit3k to testtools.
Diffstat (limited to 'setup.py')
-rw-r--r--setup.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/setup.py b/setup.py
index abc7ee1..d8dd8e6 100644
--- a/setup.py
+++ b/setup.py
@@ -1,12 +1,12 @@
"""Distutils installer for pyunit3k."""
from distutils.core import setup
-setup(name='pyunit3k',
+setup(name='testtools',
author='Jonathan M. Lange',
- author_email='jml+pyunit3k@mumak.net',
- url='https://launchpad.net/pyunit3k',
+ author_email='jml+testtools@mumak.net',
+ url='https://launchpad.net/testtools',
description=('Extensions to the Python standard library unit testing '
'framework'),
version='0.0.1',
- packages=['pyunit3k'])
+ packages=['testtools'])
@@ -1,12 +1,12 @@
-"""Distutils installer for pyunit3k."""
+"""Distutils installer for testtools."""
from distutils.core import setup